scopus.ScopusAuthor
===================

.. currentmodule:: scopus

.. autoclass:: ScopusAuthor
   
   .. rubric:: Methods

   .. autosummary::
   
      ~ScopusAuthor.author_impact_factor
      ~ScopusAuthor.get_abstracts
      ~ScopusAuthor.get_coauthors
      ~ScopusAuthor.get_document_eids
      ~ScopusAuthor.get_document_summary
      ~ScopusAuthor.n_first_author_papers
      ~ScopusAuthor.n_journal_articles
      ~ScopusAuthor.n_last_author_papers
      ~ScopusAuthor.n_yearly_publications
      
   .. rubric:: Attributes

   .. autosummary::
   
      ~ScopusAuthor.affiliation_history
      ~ScopusAuthor.author_id
      ~ScopusAuthor.citedby_url
      ~ScopusAuthor.coauthor_url
      ~ScopusAuthor.current_affiliation
      ~ScopusAuthor.date_created
      ~ScopusAuthor.firstname
      ~ScopusAuthor.hindex
      ~ScopusAuthor.lastname
      ~ScopusAuthor.name
      ~ScopusAuthor.ncited_by
      ~ScopusAuthor.ncoauthors
      ~ScopusAuthor.ndocuments
      ~ScopusAuthor.orcid
      ~ScopusAuthor.scopus_url
